<?php
require("index.common.php");

function select_move($options, $srcid, $destid) {
	$objResponse = new xajaxResponse();
	foreach($options as $option) {
		$value = $option[0];
		$text = $option[1];
		$objResponse->create($destid, "option", "$destid$value");
		$objResponse->assign("$destid$value", "value", $value);
		$objResponse->assign("$destid$value", "innerHTML", $text);
		$objResponse->remove("$srcid$value");
	}
	//print_r(array($options, $srcid, $destid));
	return $objResponse;
}

function history($string)
{
	$objResponse = new xajaxResponse();
	$objResponse->assign("content", "innerHTML", "History");
	$objResponse->assign("submenu", "style.display", "none");
	return $objResponse;
}


function html_adminSubMenu()
{
	$html = "<li><a href='#' onclick='setSearchType(\"off\");xajax_gp_display(\"\");return false;'>" . _("Preferences") . "</a></li>";
	$html .= "<li><a href='#' onclick='setSearchType(\"admin_user\");xajax_ulist_search(\"\");return false;'>" . _("Users") . "</a></li>";
	$html .= "<li><a href='#' onclick='setSearchType(\"admin_group\");xajax_glist_search(\"\");return false;'>" . _("Groups") . "</a></li>";
	return $html;
}

function admin()
{
	//$objResponse = new xajaxResponse();
	//$objResponse->assign("content", "innerHTML", "");
	$objResponse = gp_display();
	$objResponse->assign("submenu", "innerHTML", html_adminSubMenu());
	$objResponse->assign("submenu", "style.display", "block");
	return $objResponse;
}

function do_dial($src, $callerid, $dest)
{
	require("ami.php");
	$ami = new AMI();

	$objResponse = new xajaxResponse();
	if(!$ami->login())
		return $ami->error;

	if(!$ami->dial($src, $callerid, $dest)) {
		return $ami->error;
	}
	$ami->logout();
	return;
}

function dial($dest)
{
	$ret = do_dial($_SESSION['ext'], $_SESSION['callerid'], $dest);

	$objResponse = new xajaxResponse();
	if($ret)
		$objResponse->alert($ret);

	return $objResponse;
}

$xajax->processRequest();
?>
